@@ -9,19 +9,19 @@
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
 
-#include <kidentitymanagement/identitymanager.h>
-#include <MessageComposer/AkonadiSender>
-#include <MailCommon/FolderCollectionMonitor>
-#include <AkonadiCore/session.h>
-#include <AkonadiCore/entitytreemodel.h>
-#include <AkonadiCore/entitymimetypefiltermodel.h>
-#include <AkonadiCore/changerecorder.h>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/EntityTreeModel>
 #include <Akonadi/Notes/NoteUtils>
-#include <KCalendarCore/Todo>
+#include <Akonadi/Session>
 #include <KCalendarCore/Event>
+#include <KCalendarCore/Todo>
+#include <KIdentityManagement/IdentityManager>
 #include <KSharedConfig>
+#include <MailCommon/FolderCollectionMonitor>
+#include <MessageComposer/AkonadiSender>
 
-//Same element as kalarmcal
+// Same element as kalarmcal
 const QLatin1String MIME_ACTIVE("application/x-vnd.kde.alarm.active");
 const QLatin1String MIME_ARCHIVED("application/x-vnd.kde.alarm.archived");
 const QLatin1String MIME_TEMPLATE("application/x-vnd.kde.alarm.template");
